/**
 * Copyright (c) 2011-2012 EBM WebSourcing, 2012-2013 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see <http://www.gnu.org/licenses/>
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.se.xslt.model;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertTrue;

import java.util.logging.Logger;

import javax.xml.transform.TransformerFactory;

import org.junit.Test;
import org.ow2.petals.component.framework.api.exception.PEtALSCDKException;

/**
 * @author Nicolas Oddoux - EBM WebSourcing
 */
public class XsltConfigurationHandlerTest {

    @Test
    public void testCreateTransformerFactoryOKWithTransformerFactoryEqualsToNull() throws Exception {
        TransformerFactory transformerFactory = XsltConfigurationHandler.createTransformerFactory(Logger.getAnonymousLogger(), "logPrefix", null, true);
        Class<?> transformerFactoryClass = transformerFactory.getClass();
        Class<?> defaultTransformerFactoryClass = TransformerFactory.newInstance().getClass();
        assertEquals(transformerFactoryClass, defaultTransformerFactoryClass);
    }
    
    @Test
    public void testCreateTransformerFactoryOKWithXalanTransformerFactory() throws Exception {
        TransformerFactory transformerFactory = XsltConfigurationHandler.createTransformerFactory(Logger.getAnonymousLogger(), "logPrefix", "org.apache.xalan.processor.TransformerFactoryImpl", true);
        assertTrue(transformerFactory instanceof org.apache.xalan.processor.TransformerFactoryImpl);
    }
    
    @Test(expected = PEtALSCDKException.class)
    public void testCreateTransformerFactoryKOBecauseOfWrongClass() throws Exception {
        XsltConfigurationHandler.createTransformerFactory(Logger.getAnonymousLogger(), "logPrefix", "org.junit.Test", true);
    }

    @Test(expected = PEtALSCDKException.class)
    public void testCreateTransformerFactoryKOIllegalAccessException() throws Exception {
        XsltConfigurationHandler.createTransformerFactory(Logger.getAnonymousLogger(), "logPrefix", "javax.xml.transform.Transformer", true);
    }
    
    @Test(expected = PEtALSCDKException.class)
    public void testCreateTransformerFactoryKOBecauseOfUnexistingClass() throws Exception {
        XsltConfigurationHandler.createTransformerFactory(Logger.getAnonymousLogger(), "logPrefix", "org.apache.xalan.processor.TranformerFactoryImpl", true);      
    }
}
